searchData={"items":[{"type":"module","title":"Exto","doc":"[![hex.pm](https://img.shields.io/hexpm/v/exto)](https://hex.pm/packages/exto)\n[hexdocs](https://hexdocs.pm/exto)\n\n`Exto` provides configuration-driven Ecto schema extensibility","ref":"Exto.html"},{"type":"module","title":"Usage - Exto","doc":"#","ref":"Exto.html#module-usage"},{"type":"module","title":"Example Schema - Exto","doc":"```elixir\ndefmodule My.Schema do\n  use Ecto.Schema\n  import Exto, only: [flex_schema: 1]\n\n  schema \"my_table\" do\n    field :name, :string # just normal schema things\n    flex_schema(:my_app) # boom! give me the stuff\n  end\nend\n```\n\nOr if you want the `Access` protocol to be auto-implemented on the struct (because [the reasoning](https://hexdocs.pm/elixir/Access.html#module-maps-and-structs) for not having it on structs doesn't apply as much when using Exto), you can pull in the `Accessible` library by simply using `use Exto` instead of `import Exto`.\n\n#","ref":"Exto.html#module-example-schema"},{"type":"module","title":"Example configuration - Exto","doc":"```elixir\nconfig :my_app, My.Schema,\n  belongs_to: [\n    foo: Foo,                   # belongs_to :foo, Foo\n    bar: {Bar, type: :integer}, # belongs_to :bar, Bar, type: :integer\n  ],\n  field: [\n    foo: :string,                # field :foo, :string\n    bar: {:integer, default: 4}, # field :foo, :integer, default: 4\n  ],\n  has_one: [\n    foo: Foo,                             # has_one :foo, Foo\n    bar: {Bar, foreign_key: :the_bar_id}, # has_one :bar, Bar, foreign_key: :the_bar_id\n  ]\n  has_many: [\n    foo: Foo,                             # has_many :foo, Foo\n    bar: {Bar, foreign_key: :the_bar_id}, # has_many :bar, Bar, foreign_key: :the_bar_id\n  ]\n  many_to_many: [\n    foo: Foo,                         # many_to_many :foo, Foo\n    bar: {Bar, join_through: FooBar}, # many_to_many :bar, Bar, :join_through: FooBar\n  ]\n```\n\nThis example won't work very well because it is redefining `foo` and `bar` 5 times, but you get the point.\n\nReading of configuration is done during compile time. The relations will be baked in during compilation, thus:\n\n* Do not expect this to work in runtime config.\n* You will need to rebuild all dependencies which use this macro when you change their configuration.","ref":"Exto.html#module-example-configuration"},{"type":"module","title":"Copyright and License - Exto","doc":"Copyright (c) 2020 Exto Contributors\n\n Licensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\n   http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"Exto.html#module-copyright-and-license"},{"type":"macro","title":"Exto.flex_schema/1","doc":"Adds additional associations dynamically based on the config found under the name of the current module for the given OTP application. \n\nEach key maps to an Ecto.Schema function:\n\n* `belongs_to`\n* `field`\n* `has_many`\n* `has_one`\n* `many_to_many`\n\nEach of these keys should map to a keyword list where the key is the name of the field or association and the value is one of:\n\n* A type\n* A tuple of type and options (keyword list)","ref":"Exto.html#flex_schema/1"},{"type":"extras","title":"Exto","doc":"# Exto\n\n[![hex.pm](https://img.shields.io/hexpm/v/exto)](https://hex.pm/packages/exto)\n[hexdocs](https://hexdocs.pm/exto)\n\n`Exto` provides configuration-driven Ecto schema extensibility","ref":"readme.html"},{"type":"extras","title":"Usage - Exto","doc":"#","ref":"readme.html#usage"},{"type":"extras","title":"Example Schema - Exto","doc":"```elixir\ndefmodule My.Schema do\n  use Ecto.Schema\n  import Exto, only: [flex_schema: 1]\n\n  schema \"my_table\" do\n    field :name, :string # just normal schema things\n    flex_schema(:my_app) # boom! give me the stuff\n  end\nend\n```\n\nOr if you want the `Access` protocol to be auto-implemented on the struct (because [the reasoning](https://hexdocs.pm/elixir/Access.html#module-maps-and-structs) for not having it on structs doesn't apply as much when using Exto), you can pull in the `Accessible` library by simply using `use Exto` instead of `import Exto`.\n\n#","ref":"readme.html#example-schema"},{"type":"extras","title":"Example configuration - Exto","doc":"```elixir\nconfig :my_app, My.Schema,\n  belongs_to: [\n    foo: Foo,                   # belongs_to :foo, Foo\n    bar: {Bar, type: :integer}, # belongs_to :bar, Bar, type: :integer\n  ],\n  field: [\n    foo: :string,                # field :foo, :string\n    bar: {:integer, default: 4}, # field :foo, :integer, default: 4\n  ],\n  has_one: [\n    foo: Foo,                             # has_one :foo, Foo\n    bar: {Bar, foreign_key: :the_bar_id}, # has_one :bar, Bar, foreign_key: :the_bar_id\n  ]\n  has_many: [\n    foo: Foo,                             # has_many :foo, Foo\n    bar: {Bar, foreign_key: :the_bar_id}, # has_many :bar, Bar, foreign_key: :the_bar_id\n  ]\n  many_to_many: [\n    foo: Foo,                         # many_to_many :foo, Foo\n    bar: {Bar, join_through: FooBar}, # many_to_many :bar, Bar, :join_through: FooBar\n  ]\n```\n\nThis example won't work very well because it is redefining `foo` and `bar` 5 times, but you get the point.\n\nReading of configuration is done during compile time. The relations will be baked in during compilation, thus:\n\n* Do not expect this to work in runtime config.\n* You will need to rebuild all dependencies which use this macro when you change their configuration.","ref":"readme.html#example-configuration"},{"type":"extras","title":"Copyright and License - Exto","doc":"Copyright (c) 2020 Exto Contributors\n\n Licensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\n   http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"readme.html#copyright-and-license"}],"content_type":"text/markdown"}